# NUFFT

::: torchlinops.linops.NUFFT
    options:
        inherited_members: false
        members:
            - __init__
            - normal
            - prep_locs

::: torchlinops.linops.nufft.toeplitz_psf

::: torchlinops.linops.nufft.rescale_locs
